==> qore-0.8.10.tar.bz2: qore-0.8.10/docs/lang/html/group__dbi__capabilities.js <==
var group__dbi__capabilities =
[
    [ "DBI_CAP_AUTORECONNECT", "group__dbi__capabilities.html#gae77508d8a9b7f53e3f0a35f76cf59511", null ],
    [ "DBI_CAP_BIND_BY_PLACEHOLDER", "group__dbi__capabilities.html#gac6adedead4bf1317f03b575dc1276351", null ],
    [ "DBI_CAP_BIND_BY_VALUE", "group__dbi__capabilities.html#ga369027092e18434a428c0ba401986964", null ],
    [ "DBI_CAP_CHARSET_SUPPORT", "group__dbi__capabilities.html#ga382bb241f164431cf2e5c0e161b1bdd2", null ],
    [ "DBI_CAP_EVENTS", "group__dbi__capabilities.html#gae187e09b0775647d1b1afd2d3b43570f", null ],
    [ "DBI_CAP_HAS_DESCRIBE", "group__dbi__capabilities.html#ga775d0748c664e8ced5a2ef953496aa8c", null ],
    [ "DBI_CAP_HAS_EXECRAW", "group__dbi__capabilities.html#gad3033ee84e18d57a95da98e01bdae383", null ],
    [ "DBI_CAP_HAS_NUMBER_SUPPORT", "group__dbi__capabilities.html#ga8394d1495944bf61d666de40489a038a", null ],
    [ "DBI_CAP_HAS_OPTION_SUPPORT", "group__dbi__capabilities.html#ga428f8f4909b2737d03593d8808fe2227", null ],
    [ "DBI_CAP_HAS_SELECT_ROW", "group__dbi__capabilities.html#ga8a1c46d41ccafebf758dfe3d1116657c", null ],
    [ "DBI_CAP_HAS_STATEMENT", "group__dbi__capabilities.html#ga527e40359b876f12a4cb59fec305969d", null ],
    [ "DBI_CAP_LOB_SUPPORT", "group__dbi__capabilities.html#ga3a641cb4afbeb873fd9fe97f020f09eb", null ],
    [ "DBI_CAP_SERVER_TIME_ZONE", "group__dbi__capabilities.html#ga9edf0826e734f77115fd8f1001cf4a9e", null ],
    [ "DBI_CAP_STORED_PROCEDURES", "group__dbi__capabilities.html#gac5e26138ae8e0957e7dba50d8a96cb6c", null ],
    [ "DBI_CAP_TIME_ZONE_SUPPORT", "group__dbi__capabilities.html#gab97795225e7b52a4a063c1770c4fec7c", null ],
    [ "DBI_CAP_TRANSACTION_MANAGEMENT", "group__dbi__capabilities.html#ga62b0bd7a4e0611fbe8848002aa6711c8", null ]
];

==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/lang/html/group__dbi__capabilities.js <==
var group__dbi__capabilities =
[
    [ "DBI_CAP_AUTORECONNECT", "group__dbi__capabilities.html#gae77508d8a9b7f53e3f0a35f76cf59511", null ],
    [ "DBI_CAP_BIND_BY_PLACEHOLDER", "group__dbi__capabilities.html#gac6adedead4bf1317f03b575dc1276351", null ],
    [ "DBI_CAP_BIND_BY_VALUE", "group__dbi__capabilities.html#ga369027092e18434a428c0ba401986964", null ],
    [ "DBI_CAP_CHARSET_SUPPORT", "group__dbi__capabilities.html#ga382bb241f164431cf2e5c0e161b1bdd2", null ],
    [ "DBI_CAP_EVENTS", "group__dbi__capabilities.html#gae187e09b0775647d1b1afd2d3b43570f", null ],
    [ "DBI_CAP_HAS_ARRAY_BIND", "group__dbi__capabilities.html#ga87128ed8eccc517cb36ceb5f27ceaa53", null ],
    [ "DBI_CAP_HAS_DESCRIBE", "group__dbi__capabilities.html#ga775d0748c664e8ced5a2ef953496aa8c", null ],
    [ "DBI_CAP_HAS_EXECRAW", "group__dbi__capabilities.html#gad3033ee84e18d57a95da98e01bdae383", null ],
    [ "DBI_CAP_HAS_NUMBER_SUPPORT", "group__dbi__capabilities.html#ga8394d1495944bf61d666de40489a038a", null ],
    [ "DBI_CAP_HAS_OPTION_SUPPORT", "group__dbi__capabilities.html#ga428f8f4909b2737d03593d8808fe2227", null ],
    [ "DBI_CAP_HAS_SELECT_ROW", "group__dbi__capabilities.html#ga8a1c46d41ccafebf758dfe3d1116657c", null ],
    [ "DBI_CAP_HAS_STATEMENT", "group__dbi__capabilities.html#ga527e40359b876f12a4cb59fec305969d", null ],
    [ "DBI_CAP_LOB_SUPPORT", "group__dbi__capabilities.html#ga3a641cb4afbeb873fd9fe97f020f09eb", null ],
    [ "DBI_CAP_SERVER_TIME_ZONE", "group__dbi__capabilities.html#ga9edf0826e734f77115fd8f1001cf4a9e", null ],
    [ "DBI_CAP_STORED_PROCEDURES", "group__dbi__capabilities.html#gac5e26138ae8e0957e7dba50d8a96cb6c", null ],
    [ "DBI_CAP_TIME_ZONE_SUPPORT", "group__dbi__capabilities.html#gab97795225e7b52a4a063c1770c4fec7c", null ],
    [ "DBI_CAP_TRANSACTION_MANAGEMENT", "group__dbi__capabilities.html#ga62b0bd7a4e0611fbe8848002aa6711c8", null ]
];
